<p align="center">
    <img src="https://raw.githubusercontent.com/Quansight/ragna/main/docs/assets/brand/logo-lockup-vertical/logo-lockup-vertical.png" width=30%>
</p>

<hr>

A RAG orchestration framework. ⛵️

## Local development

- [Setup](https://ragna.chat/en/stable/install/)
- [Quickstart](https://ragna.chat/en/stable/tutorials/python-api/)

## Code of Conduct

This repository is governed by the
[Quansight Repository Code of Conduct](https://github.com/Quansight/.github/blob/master/CODE_OF_CONDUCT.md).
